bayez
=====

A package for Bayesian redshift estimation, developed for DESI.

Status reports for developers
-----------------------------

.. image:: https://travis-ci.org/dkirkby/bayez.png?branch=master
    :target: https://travis-ci.org/dkirkby/bayez
    :alt: Test Status

.. image:: https://readthedocs.org/projects/bayez/badge/?version=latest
    :target: https://readthedocs.org/projects/bayez/?badge=latest
    :alt: Documentation Status

.. image:: https://coveralls.io/repos/dkirkby/bayez/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/dkirkby/bayez?branch=master
    :alt: Coverage Status

.. image:: https://img.shields.io/pypi/v/bayez.svg
    :target: https://pypi.python.org/pypi/bayez
    :alt: Distribution Status
